@@ -5,8 +5,8 @@ mod sync_fetch;
 use crate::web_worker::WebWorkerInternalHandle;
 use crate::web_worker::WebWorkerType;
 use deno_core::error::AnyError;
-use deno_core::op_async;
-use deno_core::op_sync;
+use deno_core::op;
+
 use deno_core::CancelFuture;
 use deno_core::Extension;
 use deno_core::OpState;
@@ -19,30 +19,29 @@ use self::sync_fetch::op_worker_sync_fetch;
 pub fn init() -> Extension {
   Extension::builder()
     .ops(vec![
-      ("op_worker_post_message", op_sync(op_worker_post_message)),
-      ("op_worker_recv_message", op_async(op_worker_recv_message)),
+      op_worker_post_message::decl(),
+      op_worker_recv_message::decl(),
       // Notify host that guest worker closes.
-      ("op_worker_close", op_sync(op_worker_close)),
-      ("op_worker_get_type", op_sync(op_worker_get_type)),
-      ("op_worker_sync_fetch", op_sync(op_worker_sync_fetch)),
+      op_worker_close::decl(),
+      op_worker_get_type::decl(),
+      op_worker_sync_fetch::decl(),
     ])
     .build()
 }
 
+#[op]
 fn op_worker_post_message(
   state: &mut OpState,
   data: JsMessageData,
-  _: (),
 ) -> Result<(), AnyError> {
   let handle = state.borrow::<WebWorkerInternalHandle>().clone();
   handle.port.send(state, data)?;
   Ok(())
 }
 
+#[op]
 async fn op_worker_recv_message(
   state: Rc<RefCell<OpState>>,
-  _: (),
-  _: (),
 ) -> Result<Option<JsMessageData>, AnyError> {
   let handle = {
     let state = state.borrow();
@@ -55,7 +54,8 @@ async fn op_worker_recv_message(
     .await?
 }
 
-fn op_worker_close(state: &mut OpState, _: (), _: ()) -> Result<(), AnyError> {
+#[op]
+fn op_worker_close(state: &mut OpState) -> Result<(), AnyError> {
   // Notify parent that we're finished
   let mut handle = state.borrow_mut::<WebWorkerInternalHandle>().clone();
 
@@ -63,11 +63,8 @@ fn op_worker_close(state: &mut OpState, _: (), _: ()) -> Result<(), AnyError> {
   Ok(())
 }
 
-fn op_worker_get_type(
-  state: &mut OpState,
-  _: (),
-  _: (),
-) -> Result<WebWorkerType, AnyError> {
+#[op]
+fn op_worker_get_type(state: &mut OpState) -> Result<WebWorkerType, AnyError> {
   let handle = state.borrow::<WebWorkerInternalHandle>().clone();
   Ok(handle.worker_type)
 }
